==> fastapi_0.101.0.orig.tar.xz: fastapi-0.101.0/docs/em/docs/tutorial/path-operation-configuration.md <==
# ➡ 🛠️ 📳

📤 📚 🔢 👈 👆 💪 🚶‍♀️ 👆 *➡ 🛠️ 👨‍🎨* 🔗 ⚫️.

!!! warning
    👀 👈 👫 🔢 🚶‍♀️ 🔗 *➡ 🛠️ 👨‍🎨*, 🚫 👆 *➡ 🛠️ 🔢*.

## 📨 👔 📟

👆 💪 🔬 (🇺🇸🔍) `status_code` ⚙️ 📨 👆 *➡ 🛠️*.

👆 💪 🚶‍♀️ 🔗 `int` 📟, 💖 `404`.

✋️ 🚥 👆 🚫 💭 ⚫️❔ 🔠 🔢 📟, 👆 💪 ⚙️ ⌨ 📉 `status`:

=== "🐍 3️⃣.6️⃣ &amp; 🔛"

    ```Python hl_lines="3  17"
    {!> ../../../docs_src/path_operation_configuration/tutorial001.py!}
    ```

=== "🐍 3️⃣.9️⃣ &amp; 🔛"

    ```Python hl_lines="3  17"
    {!> ../../../docs_src/path_operation_configuration/tutorial001_py39.py!}
    ```

=== "🐍 3️⃣.1️⃣0️⃣ &amp; 🔛"

    ```Python hl_lines="1  15"
    {!> ../../../docs_src/path_operation_configuration/tutorial001_py310.py!}
    ```

👈 👔 📟 🔜 ⚙️ 📨 &amp; 🔜 🚮 🗄 🔗.

!!! note "📡 ℹ"
    👆 💪 ⚙️ `from starlette import status`.

    **FastAPI** 🚚 🎏 `starlette.status` `fastapi.status` 🏪 👆, 👩‍💻. ✋️ ⚫️ 👟 🔗 ⚪️➡️ 💃.

## 🔖

👆 💪 🚮 🔖 👆 *➡ 🛠️*, 🚶‍♀️ 🔢 `tags` ⏮️ `list` `str` (🛎 1️⃣ `str`):

=== "🐍 3️⃣.6️⃣ &amp; 🔛"

    ```Python hl_lines="17  22  27"
    {!> ../../../docs_src/path_operation_configuration/tutorial002.py!}
    ```

=== "🐍 3️⃣.9️⃣ &amp; 🔛"

    ```Python hl_lines="17  22  27"
    {!> ../../../docs_src/path_operation_configuration/tutorial002_py39.py!}
    ```

=== "🐍 3️⃣.1️⃣0️⃣ &amp; 🔛"

    ```Python hl_lines="15  20  25"
    {!> ../../../docs_src/path_operation_configuration/tutorial002_py310.py!}
    ```

👫 🔜 🚮 🗄 🔗 &amp; ⚙️ 🏧 🧾 🔢:

<img src="/img/tutorial/path-operation-configuration/image01.png">

### 🔖 ⏮️ 🔢

🚥 👆 ✔️ 🦏 🈸, 👆 5️⃣📆 🔚 🆙 📈 **📚 🔖**, &amp; 👆 🔜 💚 ⚒ 💭 👆 🕧 ⚙️ **🎏 🔖** 🔗 *➡ 🛠️*.

👫 💼, ⚫️ 💪 ⚒ 🔑 🏪 🔖 `Enum`.

**FastAPI** 🐕‍🦺 👈 🎏 🌌 ⏮️ ✅ 🎻:

```Python hl_lines="1  8-10  13  18"
{!../../../docs_src/path_operation_configuration/tutorial002b.py!}
```

## 📄 &amp; 📛

👆 💪 🚮 `summary` &amp; `description`:

=== "🐍 3️⃣.6️⃣ &amp; 🔛"

    ```Python hl_lines="20-21"
    {!> ../../../docs_src/path_operation_configuration/tutorial003.py!}
    ```

=== "🐍 3️⃣.9️⃣ &amp; 🔛"

    ```Python hl_lines="20-21"
    {!> ../../../docs_src/path_operation_configuration/tutorial003_py39.py!}
    ```

=== "🐍 3️⃣.1️⃣0️⃣ &amp; 🔛"

    ```Python hl_lines="18-19"
    {!> ../../../docs_src/path_operation_configuration/tutorial003_py310.py!}
    ```

## 📛 ⚪️➡️ #️⃣

📛 😑 📏 &amp; 📔 💗 ⏸, 👆 💪 📣 *➡ 🛠️* 📛 🔢 <abbr title="a multi-line string as the first expression inside a function (not assigned to any variable) used for documentation"> #️⃣ </abbr> &amp; **FastAPI** 🔜 ✍ ⚫️ ⚪️➡️ 📤.

👆 💪 ✍ <a href="https://en.wikipedia.org/wiki/Markdown" class="external-link" target="_blank">✍</a> #️⃣ , ⚫️ 🔜 🔬 &amp; 🖥 ☑ (✊ 🔘 🏧 #️⃣ 📐).

=== "🐍 3️⃣.6️⃣ &amp; 🔛"

    ```Python hl_lines="19-27"
    {!> ../../../docs_src/path_operation_configuration/tutorial004.py!}
    ```

=== "🐍 3️⃣.9️⃣ &amp; 🔛"

    ```Python hl_lines="19-27"
    {!> ../../../docs_src/path_operation_configuration/tutorial004_py39.py!}
    ```

=== "🐍 3️⃣.1️⃣0️⃣ &amp; 🔛"

    ```Python hl_lines="17-25"
    {!> ../../../docs_src/path_operation_configuration/tutorial004_py310.py!}
    ```

⚫️ 🔜 ⚙️ 🎓 🩺:

<img src="/img/tutorial/path-operation-configuration/image02.png">

## 📨 📛

👆 💪 ✔ 📨 📛 ⏮️ 🔢 `response_description`:

=== "🐍 3️⃣.6️⃣ &amp; 🔛"

    ```Python hl_lines="21"
    {!> ../../../docs_src/path_operation_configuration/tutorial005.py!}
    ```

=== "🐍 3️⃣.9️⃣ &amp; 🔛"

    ```Python hl_lines="21"
    {!> ../../../docs_src/path_operation_configuration/tutorial005_py39.py!}
    ```

=== "🐍 3️⃣.1️⃣0️⃣ &amp; 🔛"

    ```Python hl_lines="19"
    {!> ../../../docs_src/path_operation_configuration/tutorial005_py310.py!}
    ```

!!! info
    👀 👈 `response_description` 🔗 🎯 📨, `description` 🔗 *➡ 🛠️* 🏢.

!!! check
    🗄 ✔ 👈 🔠 *➡ 🛠️* 🚚 📨 📛.

    , 🚥 👆 🚫 🚚 1️⃣, **FastAPI** 🔜 🔁 🏗 1️⃣ "🏆 📨".

<img src="/img/tutorial/path-operation-configuration/image03.png">

## 😢 *➡ 🛠️*

🚥 👆 💪 ™ *➡ 🛠️* <abbr title="obsolete, recommended not to use it">😢</abbr>, ✋️ 🍵 ❎ ⚫️, 🚶‍♀️ 🔢 `deprecated`:

```Python hl_lines="16"
{!../../../docs_src/path_operation_configuration/tutorial006.py!}
```

⚫️ 🔜 🎯 ™ 😢 🎓 🩺:

<img src="/img/tutorial/path-operation-configuration/image04.png">

✅ ❔ 😢 &amp; 🚫-😢 *➡ 🛠️* 👀 💖:

<img src="/img/tutorial/path-operation-configuration/image05.png">

## 🌃

👆 💪 🔗 &amp; 🚮 🗃 👆 *➡ 🛠️* 💪 🚶‍♀️ 🔢 *➡ 🛠️ 👨‍🎨*.

==> fastapi_0.115.11.orig.tar.xz: fastapi-0.115.11/docs/em/docs/tutorial/path-operation-configuration.md <==
# ➡ 🛠️ 📳

📤 📚 🔢 👈 👆 💪 🚶‍♀️ 👆 *➡ 🛠️ 👨‍🎨* 🔗 ⚫️.

/// warning

👀 👈 👫 🔢 🚶‍♀️ 🔗 *➡ 🛠️ 👨‍🎨*, 🚫 👆 *➡ 🛠️ 🔢*.

///

## 📨 👔 📟

👆 💪 🔬 (🇺🇸🔍) `status_code` ⚙️ 📨 👆 *➡ 🛠️*.

👆 💪 🚶‍♀️ 🔗 `int` 📟, 💖 `404`.

✋️ 🚥 👆 🚫 💭 ⚫️❔ 🔠 🔢 📟, 👆 💪 ⚙️ ⌨ 📉 `status`:

{* ../../docs_src/path_operation_configuration/tutorial001.py hl[3,17] *}

👈 👔 📟 🔜 ⚙️ 📨 &amp; 🔜 🚮 🗄 🔗.

/// note | 📡 ℹ

👆 💪 ⚙️ `from starlette import status`.

**FastAPI** 🚚 🎏 `starlette.status` `fastapi.status` 🏪 👆, 👩‍💻. ✋️ ⚫️ 👟 🔗 ⚪️➡️ 💃.

///

## 🔖

👆 💪 🚮 🔖 👆 *➡ 🛠️*, 🚶‍♀️ 🔢 `tags` ⏮️ `list` `str` (🛎 1️⃣ `str`):

{* ../../docs_src/path_operation_configuration/tutorial002.py hl[17,22,27] *}

👫 🔜 🚮 🗄 🔗 &amp; ⚙️ 🏧 🧾 🔢:

<img src="/img/tutorial/path-operation-configuration/image01.png">

### 🔖 ⏮️ 🔢

🚥 👆 ✔️ 🦏 🈸, 👆 5️⃣📆 🔚 🆙 📈 **📚 🔖**, &amp; 👆 🔜 💚 ⚒ 💭 👆 🕧 ⚙️ **🎏 🔖** 🔗 *➡ 🛠️*.

👫 💼, ⚫️ 💪 ⚒ 🔑 🏪 🔖 `Enum`.

**FastAPI** 🐕‍🦺 👈 🎏 🌌 ⏮️ ✅ 🎻:

{* ../../docs_src/path_operation_configuration/tutorial002b.py hl[1,8:10,13,18] *}

## 📄 &amp; 📛

👆 💪 🚮 `summary` &amp; `description`:

{* ../../docs_src/path_operation_configuration/tutorial003.py hl[20:21] *}

## 📛 ⚪️➡️ #️⃣

📛 😑 📏 &amp; 📔 💗 ⏸, 👆 💪 📣 *➡ 🛠️* 📛 🔢 <abbr title="a multi-line string as the first expression inside a function (not assigned to any variable) used for documentation"> #️⃣ </abbr> &amp; **FastAPI** 🔜 ✍ ⚫️ ⚪️➡️ 📤.

👆 💪 ✍ <a href="https://en.wikipedia.org/wiki/Markdown" class="external-link" target="_blank">✍</a> #️⃣ , ⚫️ 🔜 🔬 &amp; 🖥 ☑ (✊ 🔘 🏧 #️⃣ 📐).

{* ../../docs_src/path_operation_configuration/tutorial004.py hl[19:27] *}

⚫️ 🔜 ⚙️ 🎓 🩺:

<img src="/img/tutorial/path-operation-configuration/image02.png">

## 📨 📛

👆 💪 ✔ 📨 📛 ⏮️ 🔢 `response_description`:

{* ../../docs_src/path_operation_configuration/tutorial005.py hl[21] *}

/// info

👀 👈 `response_description` 🔗 🎯 📨, `description` 🔗 *➡ 🛠️* 🏢.

///

/// check

🗄 ✔ 👈 🔠 *➡ 🛠️* 🚚 📨 📛.

, 🚥 👆 🚫 🚚 1️⃣, **FastAPI** 🔜 🔁 🏗 1️⃣ "🏆 📨".

///

<img src="/img/tutorial/path-operation-configuration/image03.png">

## 😢 *➡ 🛠️*

🚥 👆 💪 ™ *➡ 🛠️* <abbr title="obsolete, recommended not to use it">😢</abbr>, ✋️ 🍵 ❎ ⚫️, 🚶‍♀️ 🔢 `deprecated`:

{* ../../docs_src/path_operation_configuration/tutorial006.py hl[16] *}

⚫️ 🔜 🎯 ™ 😢 🎓 🩺:

<img src="/img/tutorial/path-operation-configuration/image04.png">

✅ ❔ 😢 &amp; 🚫-😢 *➡ 🛠️* 👀 💖:

<img src="/img/tutorial/path-operation-configuration/image05.png">

## 🌃

👆 💪 🔗 &amp; 🚮 🗃 👆 *➡ 🛠️* 💪 🚶‍♀️ 🔢 *➡ 🛠️ 👨‍🎨*.
